interface Result<S, F> {
    isSuccess: boolean;
    value?: S;
    isFailure: boolean;
    failure?: F;
    /**
     * Return the successful value, or throw an error if the result
     * is a failure
     */
    unwrap(): S | never;
}
/**
 * A successful result.
 * Use [[value]] or call [[unwrap]] to retreive the value.
 */
export declare class Success<T> implements Result<T, never> {
    value: T;
    constructor(value: T);
    readonly isSuccess: true;
    readonly isFailure: false;
    readonly failure: undefined;
    unwrap(): T;
}
/**
 * A failure result.
 * Use [[failure]] to retrieve the failure value.
 * Call [[unwrap]] to throw as an Error.
 */
export declare class Failure<T> implements Result<never, T> {
    failure: T;
    private unwrapper;
    constructor(failure: T, unwrapper: (error: T) => never);
    readonly isSuccess: false;
    readonly isFailure: true;
    unwrap(): never;
}
/**
 * Represents the results of an operation that can fail.
 */
export declare type SuccessOrFail<S, F> = Success<S> | Failure<F>;
export {};
